Split up patchfiles. Add patch from PR 9710. Update md5 file so it

no longer needs to be marked as broken.

PR:		9710
Submitted by:	Boris Staeblow <balu@dva.in-berlin.de>
This commit is contained in:
Michael Haro 1999-04-16 08:52:25 +00:00
parent 978f7df617
commit b5836e35bd
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=17915
8 changed files with 247 additions and 213 deletions

View File

@ -3,7 +3,7 @@
# Date created: 24 September 1994
# Whom: adam
#
# $Id: Makefile,v 1.16 1998/07/23 15:30:32 asami Exp $
# $Id: Makefile,v 1.17 1998/12/10 17:24:32 vanilla Exp $
#
DISTNAME= nn-6.5.3
@ -14,8 +14,6 @@ EXTRACT_SUFX= .tar.Z
MAINTAINER= ports@FreeBSD.ORG
BROKEN= checksum
MAN1= nn.1 nncheck.1 nngoback.1 nngrab.1 nngrep.1 nnpost.1 \
nntidy.1 nnview.1 nnacct.1m nnadmin.1m nnstats.1m nnusage.1m
MAN8= nnmaster.8 nnspew.8

View File

@ -1 +1 @@
MD5 (nn-6.5.3.tar.Z) = 324a188c9c5efaffc9f9a267c7b9e368
MD5 (nn-6.5.3.tar.Z) = 20d983d62b2f89deda855485405099ed

View File

@ -1,209 +1,10 @@
*** config.h Mon Jul 20 10:27:15 1998
--- config.h.new Mon Jul 20 10:55:32 1998
***************
*** 51,60 ****
#define DO_NOV_DIGEST /* */
/* Optional */
! /* #define NOV_DIRECTORY "/usr/spool/news" /* */
/* Optional */
! /* #define NOV_FILENAME ".overview" /* */
/*********************** NETWORK DEPENDENT DEFINITIONS **********************
--- 51,60 ----
#define DO_NOV_DIGEST /* */
/* Optional */
! #define NOV_DIRECTORY "/var/news/over.view" /* */
/* Optional */
! #define NOV_FILENAME ".overview" /* */
/*********************** NETWORK DEPENDENT DEFINITIONS **********************
***************
*** 107,113 ****
* NOTE: If you plan to use the included inews, it MUST be a full pathname
*/
! #define NNTP_SERVER "/usr/lib/nntp_server" /* */
/*
* Define NNTP_POST if you want nn to reject attempts to post via
--- 107,113 ----
* NOTE: If you plan to use the included inews, it MUST be a full pathname
*/
! #define NNTP_SERVER "/usr/local/etc/nntp_server" /* */
/*
* Define NNTP_POST if you want nn to reject attempts to post via
***************
*** 149,155 ****
* conf/s-template.h as a starting point for writing you own.
*/
! #include "s-hpux9-0.h"
/*
* Define DEFAULT_PAGER as the initial value of the 'pager' variable.
--- 149,155 ----
* conf/s-template.h as a starting point for writing you own.
*/
! #include "s-freebsd.h"
/*
* Define DEFAULT_PAGER as the initial value of the 'pager' variable.
***************
*** 210,216 ****
* conf/m-template.h as a starting point for writing you own.
*/
! #include "m-hp9000.h"
/***************************** OWNERSHIP ***************************
--- 210,216 ----
* conf/m-template.h as a starting point for writing you own.
*/
! #include "m-i80386.h"
/***************************** OWNERSHIP ***************************
***************
*** 263,269 ****
#define BIN_DIRECTORY "/usr/local/bin"
#define LIB_DIRECTORY "/usr/local/lib/nn"
!
/**************************** DATABASE LOCATION **************************
*
--- 263,269 ----
#define BIN_DIRECTORY "/usr/local/bin"
#define LIB_DIRECTORY "/usr/local/lib/nn"
! #define TMP_DIRECTORY "/var/tmp"
/**************************** DATABASE LOCATION **************************
*
***************
*** 294,300 ****
* (The file system must support long file names!!)
*/
! /* #define DB_DIRECTORY "/usr/spool/nn" /* */
/*************************** NEWS TRANSPORT **************************
--- 294,300 ----
* (The file system must support long file names!!)
*/
! #define DB_DIRECTORY "/var/spool/nn" /* */
/*************************** NEWS TRANSPORT **************************
***************
*** 316,323 ****
* Default: NEWS_LIB_DIR/{rm,del}group
*/
! /* #define NEWS_DIRECTORY "/usr/spool/news" /* */
! /* #define NEWS_LIB_DIRECTORY "/usr/lib/news" /* */
/* #define INEWS_PATH "/usr/lib/news/inews" /* */
--- 316,323 ----
* Default: NEWS_LIB_DIR/{rm,del}group
*/
! #define NEWS_DIRECTORY "/var/news" /* */
! #define NEWS_LIB_DIRECTORY "/usr/local/news/lib" /* */
/* #define INEWS_PATH "/usr/lib/news/inews" /* */
***************
*** 341,347 ****
*/
/* #define REC_MAIL "/usr/lib/news/recmail" /* non-sendmail */
! #define REC_MAIL "/usr/lib/sendmail -t" /* sendmail */
/*
--- 341,347 ----
*/
/* #define REC_MAIL "/usr/lib/news/recmail" /* non-sendmail */
! #define REC_MAIL "/usr/sbin/sendmail -t" /* sendmail */
/*
***************
*** 403,415 ****
* DAEMON_MAN - nnmaster
*/
! #define USER_MAN_DIR "/usr/man/man1"
#define USER_MAN_SECTION "1"
! #define SYS_MAN_DIR "/usr/man/man1"
#define SYS_MAN_SECTION "1m"
! #define DAEMON_MAN_DIR "/usr/man/man8"
#define DAEMON_MAN_SECTION "8"
--- 403,415 ----
* DAEMON_MAN - nnmaster
*/
! #define USER_MAN_DIR "/usr/local/man/man1"
#define USER_MAN_SECTION "1"
! #define SYS_MAN_DIR "/usr/local/man/man1"
#define SYS_MAN_SECTION "1m"
! #define DAEMON_MAN_DIR "/usr/local/man/man8"
#define DAEMON_MAN_SECTION "8"
***************
*** 469,475 ****
* was accepted, whereas with INN, it only takes seconds.
*/
! #define INEWS_IS_FAST /* comment out for C-News */
/*
* Synchronous posting: If set this will cause NN to wait until a
--- 469,475 ----
* was accepted, whereas with INN, it only takes seconds.
*/
! /*#define INEWS_IS_FAST*/ /* comment out for C-News */
/*
* Synchronous posting: If set this will cause NN to wait until a
***************
*** 481,487 ****
* via some sort of NNTP.
*/
! #define SYNCHRONOUS_POSTING /* comment out for C-News */
/*
* PUT_TIMESTAMP_IN_SCRIPTS
--- 481,487 ----
* via some sort of NNTP.
*/
! /*#define SYNCHRONOUS_POSTING /* comment out for C-News */
/*
* PUT_TIMESTAMP_IN_SCRIPTS
--- chset.c.orig Fri Apr 28 22:34:04 1995
+++ chset.c Fri Apr 16 01:30:09 1999
@@ -18,6 +18,7 @@
"iso-8859-7", 8,
"iso-8859-8", 8,
"iso-8859-9", 8,
+ "koi8-r", 8,
"unknown", 0,
NULL, 0,
};

22
news/nn/files/patch-ac Normal file
View File

@ -0,0 +1,22 @@
--- sort.c.orig Fri Apr 28 22:35:13 1995
+++ sort.c Fri Apr 16 01:30:09 1999
@@ -43,6 +43,29 @@
* before MATCH_?? (t, a, b) is used.
*/
+#ifdef HAVE_WORKING_COLLATE
+
+#ifdef HAVE_8BIT_CTYPE
+#define MATCH_DROP(table, c) !isprint(c)
+#else
+#define MATCH_DROP(table, c) ( c & 0200 || !isprint(c) )
+#endif
+#define MATCH_EQ(table, a, b) ( a == b || table(a, b) == 0 )
+#define MATCH_LS_EQ(table, a, b) ( a == b || table(a, b) <= 0 )
+#define MATCH_LS(table, a, b) ( table(a, b) < 0 )
+#define MATCH_CMP(table, a, b) table(a, b)
+
+static int match_subject(a, b)
+char a, b;
+{
+ static char aa[2], bb[2];
+
+ aa[0] = a; bb[0] = b;
+ return strcoll(aa, bb);
+}
+
+#else
+
#define MATCH_DROP(table, c) ( c & 0200 || table[c] == 0 )
#define MATCH_EQ(table, a, b) ( a == b || table[a] == table[b] )
#define MATCH_LS_EQ(table, a, b) ( a <= b || table[a] <= table[b] )
@@ -77,6 +100,7 @@
26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 00, 00
};
+#endif /* HAVE_WORKING_COLLATE */
static int
order_subj_date(ah1, ah2)

115
news/nn/files/patch-ae Normal file
View File

@ -0,0 +1,115 @@
--- config.h.orig Fri Apr 16 01:30:09 1999
+++ config.h Fri Apr 16 01:30:09 1999
@@ -51,10 +51,10 @@
#define DO_NOV_DIGEST /* */
/* Optional */
-/* #define NOV_DIRECTORY "/usr/spool/news" /* */
+#define NOV_DIRECTORY "/var/news/over.view" /* */
/* Optional */
-/* #define NOV_FILENAME ".overview" /* */
+#define NOV_FILENAME ".overview" /* */
/*********************** NETWORK DEPENDENT DEFINITIONS **********************
@@ -107,7 +107,7 @@
* NOTE: If you plan to use the included inews, it MUST be a full pathname
*/
-#define NNTP_SERVER "/usr/lib/nntp_server" /* */
+#define NNTP_SERVER "/usr/local/etc/nntp_server" /* */
/*
* Define NNTP_POST if you want nn to reject attempts to post via
@@ -149,7 +149,7 @@
* conf/s-template.h as a starting point for writing you own.
*/
-#include "s-hpux9-0.h"
+#include "s-freebsd.h"
/*
* Define DEFAULT_PAGER as the initial value of the 'pager' variable.
@@ -210,7 +210,7 @@
* conf/m-template.h as a starting point for writing you own.
*/
-#include "m-hp9000.h"
+#include "m-i80386.h"
/***************************** OWNERSHIP ***************************
@@ -263,7 +263,7 @@
#define BIN_DIRECTORY "/usr/local/bin"
#define LIB_DIRECTORY "/usr/local/lib/nn"
-
+#define TMP_DIRECTORY "/var/tmp"
/**************************** DATABASE LOCATION **************************
*
@@ -294,7 +294,7 @@
* (The file system must support long file names!!)
*/
-/* #define DB_DIRECTORY "/usr/spool/nn" /* */
+#define DB_DIRECTORY "/var/spool/nn" /* */
/*************************** NEWS TRANSPORT **************************
@@ -316,8 +316,8 @@
* Default: NEWS_LIB_DIR/{rm,del}group
*/
-/* #define NEWS_DIRECTORY "/usr/spool/news" /* */
-/* #define NEWS_LIB_DIRECTORY "/usr/lib/news" /* */
+#define NEWS_DIRECTORY "/var/news" /* */
+#define NEWS_LIB_DIRECTORY "/usr/local/news/lib" /* */
/* #define INEWS_PATH "/usr/lib/news/inews" /* */
@@ -341,7 +341,7 @@
*/
/* #define REC_MAIL "/usr/lib/news/recmail" /* non-sendmail */
-#define REC_MAIL "/usr/lib/sendmail -t" /* sendmail */
+#define REC_MAIL "/usr/sbin/sendmail -t" /* sendmail */
/*
@@ -403,13 +403,13 @@
* DAEMON_MAN - nnmaster
*/
-#define USER_MAN_DIR "/usr/man/man1"
+#define USER_MAN_DIR "/usr/local/man/man1"
#define USER_MAN_SECTION "1"
-#define SYS_MAN_DIR "/usr/man/man1"
+#define SYS_MAN_DIR "/usr/local/man/man1"
#define SYS_MAN_SECTION "1m"
-#define DAEMON_MAN_DIR "/usr/man/man8"
+#define DAEMON_MAN_DIR "/usr/local/man/man8"
#define DAEMON_MAN_SECTION "8"
@@ -469,7 +469,7 @@
* was accepted, whereas with INN, it only takes seconds.
*/
-#define INEWS_IS_FAST /* comment out for C-News */
+/*#define INEWS_IS_FAST*/ /* comment out for C-News */
/*
* Synchronous posting: If set this will cause NN to wait until a
@@ -481,7 +481,7 @@
* via some sort of NNTP.
*/
-#define SYNCHRONOUS_POSTING /* comment out for C-News */
+/*#define SYNCHRONOUS_POSTING /* comment out for C-News */
/*
* PUT_TIMESTAMP_IN_SCRIPTS

29
news/nn/files/patch-ag Normal file
View File

@ -0,0 +1,29 @@
--- Makefile.orig Mon Aug 19 17:28:12 1996
+++ Makefile Fri Apr 16 01:28:02 1999
@@ -19,15 +19,15 @@
# Use /lib/cpp or /usr/ccs/lib/cpp for CPP on Solaris or SVR4 machines.
CC = cc
-#CPP = $(CC) -E
-CPP = /lib/cpp
-#CFLAGS = -O2 # -g # -I/usr/local/lib/malloc-debug -DMALLOC_FUNC_CHECK
-CFLAGS = -O
+CPP = $(CC) -E
+#CPP = /lib/cpp
+CFLAGS += -O2 # -g # -I/usr/local/lib/malloc-debug -DMALLOC_FUNC_CHECK
+#CFLAGS = -O
#-Wall -Wcomment \
#-Wtraditional -Wshadow \
#-Wpointer-arith -Wcast-qual -Wcast-align -Wconversion \
#-Waggregate-return -Wmissing-prototypes -Wnested-externs
-#LDFLAGS = -s # -lmalloc # /usr/local/lib/malloc-debug/libmalloc.a
+LDFLAGS = -s # -lmalloc # /usr/local/lib/malloc-debug/libmalloc.a
MAKE = make
@@ -97,3 +97,5 @@
man/nn.1.D: man/nn.1
sh SPLITNN1
+install:
+ ./inst n

29
news/nn/files/patch-ah Normal file
View File

@ -0,0 +1,29 @@
--- nn.c.orig Fri Jul 17 08:32:08 1998
+++ nn.c Fri Apr 16 01:41:04 1999
@@ -394,7 +394,7 @@
fl;
mode = 0;
- if (gets(answer1)) {
+ if (fgets(answer1, sizeof(answer1), stdin)) {
if (strncmp(answer1, "auto", 4) == 0) {
tprintf("\nUPDATING .newsrc FILE....");
fl;
@@ -437,7 +437,7 @@
(long)(gh->last_db_article - gh->last_article));
fl;
- if (gets(answer1) == NULL || s_keyboard)
+ if (fgets(answer1, sizeof(answer1), stdin) == NULL || s_keyboard)
*answer1 = 'q';
switch (*answer1) {
@@ -446,7 +446,7 @@
tputc(NL);
tprintf("Update rest? (yn) n\b");
fl;
- if (gets(answer1) == NULL || *answer1 != 'y')
+ if (fgets(answer1, sizeof(answer1), stdin) == NULL || *answer1 != 'y')
return;
mode = -1;
--- inst.sh.orig Fri Apr 28 22:34:49 1995
+++ inst.sh Fri Apr 16 01:30:09 1999
@@ -1,8 +1,8 @@
# (Large) prefix inserted above by Make
-# BSD systems keep chown in /etc
-PATH="$PATH:/etc"
+# BSD systems keep chown in /usr/sbin
+PATH="$PATH:/usr/sbin"
case "$1" in
mkdir)
@@ -55,7 +55,7 @@
;;
esac
-set -u
+#set -u
(
if $NNTP

40
news/nn/files/patch-ad Normal file
View File

@ -0,0 +1,40 @@